/**
 * @license Copyright (c) 2003-2024, CKSource Holding sp. z o.o. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
/**
 * @module ai/aiassistantediting
 */
import { Plugin } from 'ckeditor5/src/core.js';
import type { Position } from 'ckeditor5/src/engine.js';
/**
 * The AI assistant editing plugin.
 */
export default class AIAssistantEditing extends Plugin {
    /**
     * @inheritDoc
     */
    static get pluginName(): "AIAssistantEditing";
    /**
     * @inheritDoc
     */
    init(): void;
    /**
     * Displays a fake visual selection.
     *
     * This adds a 'ai-ui-candidate' (for the commands dropdown) or 'ai-ui' (for the assistant dialog)
     * marker into the document that is rendered as a highlight on selected text fragment.
     */
    showFakeVisualSelection(isCandidate?: boolean): void;
    /**
     * Removes a fake visual selection.
     *
     * This clears a 'ai-ui-candidate' (for the commands dropdown) or 'ai-ui' (for the assistant dialog)
     * marker from the document.
     */
    hideFakeVisualSelection(isCandidate?: boolean): void;
    /**
     * Converts the HTML string into the model fragment and inserts it at the specified position.
     *
     * If a position is not provided, the insertion will replace the visual selection marker.
     */
    insertContent(content: string, position?: Position): void;
    /**
     * Converts the HTML string into the model fragment and inserts it below the visual selection marker.
     */
    insertContentBelow(content: string): void;
}
